@@ -22,14 +22,14 @@
 #include <tqcombobox.h>
 #include <tqframe.h>
 #include <tqwidgetstack.h>
-#include <klocale.h>
+#include <tdelocale.h>
 #include <tqheader.h>
 #include <tqlayout.h>
 #include <tqvbox.h>
 #include <tqtooltip.h>
 #include <tqwhatsthis.h>
 #include <kstandarddirs.h>
-#include <kapplication.h>
+#include <tdeapplication.h>
 class _k9CheckListItem: public TQCheckListItem {
 public:
     _k9CheckListItem(TQListViewItem *_item):TQCheckListItem(_item,"",TQCheckListItem::CheckBox) {};
@@ -136,7 +136,7 @@ void k9MencoderCmdGen::listViewCurrentChanged(TQListViewItem *_item) {
 }
 
 void k9MencoderCmdGen::loadXml() {
-    TQFile file(KGlobal::dirs()->findResource( "data", "k9copy/mencoder.xml"));
+    TQFile file(TDEGlobal::dirs()->findResource( "data", "k9copy/mencoder.xml"));
     if ( !file.open( IO_ReadOnly ) )
         return;
     if ( !m_doc.setContent( &file ) ) {
